@@ -1,6 +1,6 @@
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## MCE::Candy - Sugar methods and output iterators for Many-Core Engine.
+## Sugar methods and output iterators for Many-Core Engine.
 ##
 ###############################################################################
 
@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.698_001';
+our $VERSION = '1.699_001';
 
 our @CARP_NOT = qw( MCE );
 
@@ -21,11 +21,11 @@ our @CARP_NOT = qw( MCE );
 ##
 ###############################################################################
 
-my $_loaded;
+my $_imported;
 
 sub import {
 
-   my $_class = shift; return if ($_loaded++);
+   my $_class = shift; return if ($_imported++);
 
    unless (defined $MCE::VERSION) {
       $\ = undef; require Carp;
@@ -209,7 +209,7 @@ MCE::Candy - Sugar methods and output iterators for Many-Core Engine
 
 =head1 VERSION
 
-This document describes MCE::Candy version 1.698_001
+This document describes MCE::Candy version 1.699_001
 
 =head1 DESCRIPTION
 
@@ -521,7 +521,7 @@ processing input data.
 
 =head1 INDEX
 
-L<MCE|MCE>
+L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
 
 =head1 AUTHOR
 
