@@ -1,6 +1,6 @@
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## MCE::Loop - Parallel loop model for building creative loops.
+## Parallel loop model for building creative loops.
 ##
 ###############################################################################
 
@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.698_001';
+our $VERSION = '1.699_001';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -35,10 +35,10 @@ my $TMP_DIR = $MCE::Signal::tmp_dir;
 my $FREEZE  = \&Storable::freeze;
 my $THAW    = \&Storable::thaw;
 
-my ($_MCE, $_loaded); my ($_params, $_prev_c); my $_tag = 'MCE::Loop';
+my ($_MCE, $_imported); my ($_params, $_prev_c); my $_tag = 'MCE::Loop';
 
 sub import {
-   my $_class = shift; return if ($_loaded++);
+   my $_class = shift; return if ($_imported++);
 
    ## Process module arguments.
    while (my $_argument = shift) {
@@ -100,7 +100,7 @@ sub init (@) {
    shift if (defined $_[0] && $_[0] eq 'MCE::Loop');
 
    if (MCE->wid) {
-      @_ = (); _croak("$_tag: (init) is not allowed by worker process");
+      @_ = (); _croak("$_tag: (init) is not allowed by the worker process");
    }
 
    finish(); $_params = (ref $_[0] eq 'HASH') ? shift : { @_ };
@@ -223,7 +223,7 @@ sub run (&@) {
    my $_code = shift;
 
    if (MCE->wid) {
-      @_ = (); _croak("$_tag: (run) is not allowed by worker process");
+      @_ = (); _croak("$_tag: (run) is not allowed by the worker process");
    }
 
    my $_input_data; my $_max_workers = $MAX_WORKERS; my $_r = ref $_[0];
@@ -367,7 +367,7 @@ MCE::Loop - Parallel loop model for building creative loops
 
 =head1 VERSION
 
-This document describes MCE::Loop version 1.698_001
+This document describes MCE::Loop version 1.699_001
 
 =head1 DESCRIPTION
 
@@ -528,13 +528,6 @@ Sereal if available, otherwise defaults to Storable for serialization.
 
    use MCE::Loop Sereal => 1;
 
-   MCE::Loop::init {
-      chunk_size => 1
-   };
-
-   ## Serialization is by the Sereal module if available.
-   my %answer = mce_loop { MCE->gather( $_, sqrt $_ ) } 1..10000;
-
 =head1 CUSTOMIZING MCE
 
 =over 3
@@ -638,8 +631,6 @@ optional. The format is passed to sprintf (% may be omitted below).
       begin => $beg, end => $end, step => $step, format => $fmt
    };
 
-=back
-
 The sequence engine can compute 'begin' and 'end' items only, for the chunk,
 and not the items in between (hence boundaries only). This option applies
 to sequence only and has no effect when chunk_size equals 1.
@@ -692,6 +683,8 @@ Time was measured using 1 worker to emphasize the difference.
    7500001 ..  8750000
    8750001 .. 10000000
 
+=back
+
 =head1 GATHERING DATA
 
 Unlike MCE::Map where gather and output order are done for you automatically,
@@ -887,7 +880,7 @@ longer needed.
 
 =head1 INDEX
 
-L<MCE|MCE>
+L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
 
 =head1 AUTHOR
 
