@@ -1,6 +1,6 @@
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## MCE::Subs - Exports functions mapped directly to MCE methods.
+## Exports functions mapped directly to MCE methods.
 ##
 ###############################################################################
 
@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.698_001';
+our $VERSION = '1.699_001';
 
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -25,11 +25,11 @@ use MCE::Relay;
 ##
 ###############################################################################
 
-my $_loaded;
+my $_imported;
 
 sub import {
 
-   my $_class = shift; return if ($_loaded++);
+   my $_class = shift; return if ($_imported++);
 
    my $_g_flg = 0; my $_m_flg = 0; my $_w_flg = 0;
    my $_flag = sub { 1 }; my $_package = caller;
@@ -206,7 +206,7 @@ MCE::Subs - Exports functions mapped directly to MCE methods
 
 =head1 VERSION
 
-This document describes MCE::Subs version 1.698_001
+This document describes MCE::Subs version 1.699_001
 
 =head1 SYNOPSIS
 
@@ -389,7 +389,7 @@ MCE methods are described in L<MCE::Core|MCE::Core>.
 
 =head1 INDEX
 
-L<MCE|MCE>
+L<MCE|MCE>, L<MCE::Core|MCE::Core>, L<MCE::Shared|MCE::Shared>
 
 =head1 AUTHOR
 
